@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,6 +34,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
+#include <libintl.h>
 
 #include <api/na-core-utils.h>
 
@@ -386,7 +387,7 @@ on_base_runtime_init_dialog( NactAddCapabilityDialog *dialog, gpointer user_data
 			gtk_list_store_append( model, &row );
 			gtk_list_store_set( model, &row,
 					CAPABILITY_KEYWORD_COLUMN, st_caps[i].keyword,
-					CAPABILITY_DESC_COLUMN, st_caps[i].desc,
+					CAPABILITY_DESC_COLUMN, gettext( st_caps[i].desc ),
 					CAPABILITY_ALREADY_USED_COLUMN, FALSE,
 					-1 );
 		}
@@ -547,7 +548,12 @@ try_for_send_ok( NactAddCapabilityDialog *dialog )
 
 	button = base_window_get_widget( BASE_WINDOW( dialog ), "OKButton" );
 
-#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
+/* gtk_widget_is_sensitive() appears with Gtk+ 2.17.5 released on 2009-07-18
+ * see http://git.gnome.org/browse/gtk+/commit/?id=8f6017622937770082f7b49dfbe135fae5608704
+ * GTK_WIDGET_IS_SENSITIVE macro is deprecated since 2.19.7 released on 2010-03-09
+ * see http://git.gnome.org/browse/gtk+/commit/?id=a27d5a2c9eba7af5b056de32ff9b2b4dd1eb97e1
+ */
+#if GTK_CHECK_VERSION( 2, 17, 5 )
 	is_sensitive = gtk_widget_is_sensitive( button );
 #else
 	is_sensitive = GTK_WIDGET_IS_SENSITIVE( button );
